C----------------------------------------------------------------------
C----------------------------------------------------------------------
C                               scprep.f
C----------------------------------------------------------------------
C----------------------------------------------------------------------
C
C     SlideCont
C
C     An AUTO97 driver for sliding bifurcation analysis
C
C     BY  Fabio Dercole & Yuri Kuznetsov
C
C
C     VERSION 2.0 (last revision 2/2005)
C
C----------------------------------------------------------------------
C
C     *****************************
C     *                           *
C     *  SlideCont pre-processor  *
C     *                           *
C     *****************************
C
C----------------------------------------------------------------------
C
c     ---------------
      PROGRAM SCPREP
c     ---------------
c
        IMPLICIT DOUBLE PRECISION (A-H,O-Z)
c
        INCLUDE 'slidecont.h'
        INCLUDE 'auto.h'
        INCLUDE 'debug.h'
c
c       SlideCont local variables
c       -------------------------
        INTEGER SCNDIM,SCIPS,SCIRS,SCISTART
        INTEGER SCNICP,SCICP(SCNPARX)
        INTEGER SCNPSI,SCIPSI(SCNPSIX)
        INTEGER SCNFIXED,SCIFIXED(SCNPSIX)
        INTEGER SCIDIFF,SCNTHL,SCNTHU,SCNUZR
        LOGICAL SCFPSI(SCNPSIX)
        LOGICAL SCFFIXED(SCNPSIX)
        DOUBLE PRECISION SCTHL(NPARX)
        DOUBLE PRECISION SCTHU(SCNDIMX)
        DOUBLE PRECISION SCUZR(NPARX)
        INTEGER SCITHL(NPARX)
        INTEGER SCITHU(SCNDIMX)
        INTEGER SCIUZR(NPARX)
c
c       AUTO97 local variables
c       ----------------------
        INTEGER NDIM,IPS,IRS,ILP
        INTEGER NICP,ICP(NPARX)
        INTEGER NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT
        INTEGER NMX
        DOUBLE PRECISION RL0,RL1,A0,A1
        INTEGER NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC
        DOUBLE PRECISION EPSL,EPSU,EPSS
        DOUBLE PRECISION DS,DSMIN,DSMAX
        INTEGER IADS
        INTEGER NTHL,NTHU,NUZR
        DOUBLE PRECISION THL(NPARX)
        DOUBLE PRECISION THU(NDIMX)
        DOUBLE PRECISION UZR(NPARX)
        INTEGER ITHL(NPARX)
        INTEGER ITHU(NDIMX)
        INTEGER IUZR(NPARX)
c
c       Format arrays
c       -------------
        CHARACTER*50 F(50)
        CHARACTER*80 FPROB(150)
c
c       Other local variables
c       ---------------------
        INTEGER IOVRPAR
c
c       Zero initialization
c       -------------------
        DATA SCICP/SCNPARX*0/
        DATA SCIPSI/SCNPSIX*0/
        DATA SCIFIXED/SCNPSIX*0/
        DATA SCFPSI/SCNPSIX*.FALSE./
        DATA SCFFIXED/SCNPSIX*.FALSE./
        DATA SCTHL/NPARX*0.0/
        DATA SCTHU/SCNDIMX*0.0/
        DATA SCUZR/NPARX*0.0/
        DATA SCITHL/NPARX*0/
        DATA SCITHU/SCNDIMX*0/
        DATA SCIUZR/NPARX*0/
        DATA ICP/NPARX*0/
        DATA THL/NPARX*0.0/
        DATA THU/NDIMX*0.0/
        DATA UZR/NPARX*0.0/
        DATA ITHL/NPARX*0/
        DATA ITHU/NDIMX*0/
        DATA IUZR/NPARX*0/
        DATA NICP,NTHL,NTHU,NUZR/4*0/
c
c       Open fort.2 (f.xxx) and create fort.12 (r.xxx)
c       ----------------------------------------------
        OPEN(2,FILE='fort.2',STATUS='old')
        OPEN(3,FILE='scprob.f',STATUS='unknown')
        OPEN(12,FILE='fort.12',STATUS='unknown')
c
c       Read user constants
c       -------------------
c
c       AUTO97 user constants
        READ(2,*,END=10)SCNDIM,SCIPS,SCIRS,ILP
        READ(2,*,END=10)SCNICP,(SCICP(I),I=1,SCNICP)
        READ(2,*,END=10)NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT
        READ(2,*,END=10)NMX,RL0,RL1,A0,A1
        READ(2,*,END=10)NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC
        READ(2,*,END=10)EPSL,EPSU,EPSS
        READ(2,*,END=10)DS,DSMIN,DSMAX,IADS
        READ(2,*,END=10)SCNTHL
        IF (SCNTHL.GT.0) THEN
          DO I=1,SCNTHL
            READ(2,*,END=10)SCITHL(I),SCTHL(SCITHL(I))
          END DO
        END IF
        READ(2,*,END=10)SCNTHU
        IF (SCNTHU.GT.0) THEN
          DO I=1,SCNTHU
            READ(2,*,END=10)SCITHU(I),SCTHU(SCITHU(I))
          END DO
        END IF
        READ(2,*,END=10)SCNUZR
        IF (SCNUZR.GT.0) THEN
          DO I=1,SCNUZR
            READ(2,*,END=10)SCIUZR(I),SCUZR(I)
          END DO
        END IF
c
c       SlideCont user constants
        IF (SCIPS.GE.100) THEN
          READ(2,*,END=10)SCISTART,SCIDIFF
          READ(2,*,END=10)SCNPSI,(SCIPSI(I),I=1,SCNPSI)
          READ(2,*,END=10)SCNFIXED,(SCIFIXED(I),I=1,SCNFIXED)
        END IF
c
        GOTO 20
c
c       fort.2 (f.xxx) not conformed to SlideCont constant file format
c       --------------------------------------------------------------
  10    WRITE(*,550)
        STOP
c
  20    CONTINUE
c       
c       Debug
        IF (DEBUG) THEN
          IF (DBGLEV.GE.DBGL2) THEN
            WRITE(*,FMT=110)SCNDIM,SCIPS,SCIRS,ILP
            F(1)='('
            F(2)='I10'
            DO I=1,SCNICP
              F(2+I)=','' '',I10'
            END DO
            F(3+SCNICP)=',T150,''NICP,(ICP(I),I=1,NICP)'')'
            WRITE(*,FMT=F)SCNICP,(SCICP(I),I=1,SCNICP)
            WRITE(*,FMT=130)NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT
            WRITE(*,FMT=140)NMX,RL0,RL1,A0,A1
            WRITE(*,FMT=150)NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC
            WRITE(*,FMT=160)EPSL,EPSU,EPSS
            WRITE(*,FMT=170)DS,DSMIN,DSMAX,IADS
            WRITE(*,FMT=180)SCNTHL
            WRITE(*,FMT=210)(SCITHL(I),SCTHL(SCITHL(I)),I=1,SCNTHL)
            WRITE(*,FMT=190)SCNTHU
            WRITE(*,FMT=210)(SCITHU(I),SCTHU(SCITHU(I)),I=1,SCNTHU)
            WRITE(*,FMT=200)SCNUZR
            WRITE(*,FMT=210)(SCIUZR(I),SCUZR(I),I=1,SCNUZR)
            IF (SCIPS.GE.100) THEN
              WRITE(*,FMT=220)SCISTART,SCIDIFF
              DO I=1,SCNPSI
                F(2+I)=','' '',I10'
              END DO
              F(3+SCNPSI)=',T150,''SCNPSI,(SCIPSI(I),I=1,SCNPSI)'')'
              WRITE(*,FMT=F)SCNPSI,(SCIPSI(I),I=1,SCNPSI)
              DO I=1,SCNFIXED
                F(2+I)=','' '',I10'
              END DO
              F(3+SCNFIXED)=
     +          ',T150,''SCNFIXED,(SCIFIXED(I),I=1,SCNFIXED)'')'
              WRITE(*,FMT=F)SCNFIXED,(SCIFIXED(I),I=1,SCNFIXED)
            END IF
          END IF
        END IF
c
c       Problem type selection
c       ----------------------
        IF (SCIPS.LT.100) THEN
c
c         AUTO97 problem type
c         -------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'AUTO97 problem type'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=SCIPS
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=SCNBC
          NINT=SCNINT
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.T3D1).OR.(SCIPS.EQ.T3D2)) THEN
c
c         Tangent point (SCNDIM=3)
c         ------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Tangent point (SCNDIM=3)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=0
          IRS=0
          NICP=SCNICP+1
          ICP(1)=SCIPAR0+1
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TAN1).OR.(SCIPS.EQ.TAN2)) THEN
c
c         Tangent point (SCNDIM=2)
c         ------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Tangent point (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=0
c
c         Check for double tangency continuation
          IF (ISW.EQ.2) THEN
            IRS=SCIRS
          ELSE
            IRS=0
          END IF
c
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.EQL1).OR.(SCIPS.EQ.EQL2)) THEN
c
c         Equilibrium
c         -----------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Equilibrium'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=1
c
c         Check for saddle-node or Hopf continuation
          IF (ISW.EQ.2) THEN
            IRS=SCIRS
          ELSE
            IRS=0
          END IF
c
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.BEQ1).OR.(SCIPS.EQ.BEQ2)) THEN
c
c         Boundary equilibrium
c         --------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Boundary equilibrium'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM+1
          IPS=0
          IRS=0
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NTHL=SCNTHL
          J=1
          IOVRPAR=2
          DO I=1,SCNTHL
            IF (SCITHL(I).EQ.SCICP(IOVRPAR)) THEN
              NTHU=SCNTHU+1
              NTHL=SCNTHL-1
              ITHU(SCNTHU+1)=SCNDIM+1
              THU(SCNDIM+1)=SCTHL(SCITHL(I))
            ELSE
              ITHL(J)=SCITHL(I)
              THL(ITHL(J))=SCTHL(SCITHL(I))
              J=J+1
            END IF
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF (SCIPS.EQ.BND) THEN
c
c         Discontinuity boundary (SCNDIM=2)
c         ---------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Discontinuity boundary (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=0
          IRS=0
          NICP=SCNICP+1
          ICP(1)=SCIPAR0+1
          DO I=1,SCNICP
            ICP(I+1)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          SCNTHL=0
          NTHL=SCNTHL
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF (SCIPS.EQ.PEQ) THEN
c
c         Pseudo-equilibrium
c         ------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Pseudo-equilibrium'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM+2
          IPS=0
c
c         Check for pseudo-saddle-node continuation
          IF (ISW.EQ.2) THEN
            IRS=SCIRS
          ELSE
            IRS=0
          END IF
c
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF (SCIPS.EQ.CTG) THEN
c
c         Collision of tangent points (SCNDIM=2)
c         --------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Collision of tangent points (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=3
          IPS=0
          IRS=0
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NTHL=SCNTHL
          J=1
          IOVRPAR=2
          DO I=1,SCNTHL
            IF (SCITHL(I).EQ.SCICP(IOVRPAR)) THEN
              NTHU=SCNTHU+1
              NTHL=SCNTHL-1
              ITHU(SCNTHU+1)=SCNDIM+1
              THU(SCNDIM+1)=SCTHL(SCITHL(I))
            ELSE
              ITHL(J)=SCITHL(I)
              THL(ITHL(J))=SCTHL(SCITHL(I))
              J=J+1
            END IF
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.CYC1).OR.(SCIPS.EQ.CYC2)) THEN
c
c         Cycle
c         -----
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Cycle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=2
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=0
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TGB1).OR.(SCIPS.EQ.TGB2)) THEN
c
c         Connection tangent point - discontinuity boundary (SCNDIM=2)
c         ------------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tangent point - discontinuity' //
     +          'boundary (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=3
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCB1).OR.(SCIPS.EQ.TCB2)) THEN
c
c         Connection tg. pt - crossing - disc. boundary (SCNDIM=2)
c         --------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tg. pt - crossing - ' //
     +          'disc. boundary (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PEB1).OR.(SCIPS.EQ.PEB2)) THEN
c
c         Connection pseudo-equilibrium - discontinuity boundary
c         ------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-equilibrium - ' //
     +          'discontinuity boundary'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=SCNDIM+3
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PCB1).OR.(SCIPS.EQ.PCB2)) THEN
c
c         Connection pseudo-eq. - crossing - discontinuity boundary
c         ---------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - crossing - ' //
     +          'discontinuity boundary'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=2*SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCH1).OR.(SCIPS.EQ.TCH2)) THEN
c
c         Grazing
c         -------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Grazing'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=7
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=SCNDIM+2
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TGT1).OR.(SCIPS.EQ.TGT2)) THEN
c
c         Connection tg. pt - tg. pt of the same v.f. (SCNDIM=2)
c         ------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tg. pt - tg. pt of the' //
     +          'same v.f. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCT1).OR.(SCIPS.EQ.TCT2)) THEN
c
c         Connection tg. pt - cros. - tg. pt same v.f. (SCNDIM=2)
c         -------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tg. pt - cros. - tg. pt ' //
     +          'same v.f. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TTD1).OR.(SCIPS.EQ.TTD2)) THEN
c
c         Connection tg. pt - tg. pt of different v.f. (SCNDIM=2)
c         -------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tg. pt - tg. pt of ' //
     +          'different v.f. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCD1).OR.(SCIPS.EQ.TCD2)) THEN
c
c         Connection tg. pt - cros. - tg. pt different v.f. (SCNDIM=2)
c         ------------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
               PRINT *,'Connection tg. pt - cros. - tg. pt' //
     +          'different v.f. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TGP1).OR.(SCIPS.EQ.TGP2)) THEN
c
c         Connection tangent point - pseudo-equilibrium
c         ---------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tangent point - pseudo-equilibrium'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCP1).OR.(SCIPS.EQ.TCP2)) THEN
c
c         Connection tangent point - crossing - pseudo-equilibrium
c         --------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tangent point - crossing - ' //
     +          'pseudo-equilibrium'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=2*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TGS1).OR.(SCIPS.EQ.TGS2)) THEN
c
c         Connection tangent point - saddle (SCNDIM=2)
c         --------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tangent point - saddle (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2*SCNDIM+1
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          DO I=1,SCNDIM
            ICP(SCNICP+I)=SCIPAR0+4+I
            ICP(SCNICP+SCNDIM+I)=SCIPAR0+4+SCNDIM+I
          END DO
          ICP(SCNICP+2*SCNDIM+1)=SCIPAR0+5+2*SCNDIM
          NBC=2*SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.TCS1).OR.(SCIPS.EQ.TCS2)) THEN
c
c         Connection tangent point - crossing - saddle (SCNDIM=2)
c         -------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection tangent point - crossing - ' //
     +          'saddle (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2*SCNDIM+1
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          DO I=1,SCNDIM
            ICP(SCNICP+I)=SCIPAR0+4+I
            ICP(SCNICP+SCNDIM+I)=SCIPAR0+4+SCNDIM+I
          END DO
          ICP(SCNICP+2*SCNDIM+1)=SCIPAR0+5+2*SCNDIM
          NBC=3*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PET1).OR.(SCIPS.EQ.PET2)) THEN
c
c         Connection pseudo-eq. - tangent point of the same v.f.
c         ------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - tangent point of ' //
     +          'the same v.f.'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PCT1).OR.(SCIPS.EQ.PCT2)) THEN
c
c         Connection pseudo-eq. - crossing - tg. pt of the same v.f.
c         ----------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - crossing - tg. pt' //
     +          'of the same v.f.'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=2*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PTD1).OR.(SCIPS.EQ.PTD2)) THEN
c
c         Connection pseudo-eq. - tangent point of different v.f.
c         -------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - tangent point of ' //
     +          'different v.f.'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PCD1).OR.(SCIPS.EQ.PCD2)) THEN
c
c         Connection pseudo-eq. - crossing - tg. pt of different v.f.
c         -----------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - crossing - tg. pt' //
     +          'of different v.f.'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          NBC=2*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PEP1).OR.(SCIPS.EQ.PEP2)) THEN
c
c         Connection pseudo-eq. - pseudo-eq. (SCNDIM=2)
c         ---------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - ' //
     +          'pseudo-eq. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+4
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          ICP(SCNICP+3)=SCIPAR0+3
          ICP(SCNICP+4)=SCIPAR0+4
          NBC=2*SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PCP1).OR.(SCIPS.EQ.PCP2)) THEN
c
c         Connection pseudo-eq. - crossing - pseudo-eq. (SCNDIM=2)
c         --------------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-eq. - crossing - ' //
     +          'pseudo-eq. (SCNDIM=2)'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+4
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          ICP(SCNICP+3)=SCIPAR0+3
          ICP(SCNICP+4)=SCIPAR0+4
          NBC=3*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PES1).OR.(SCIPS.EQ.PES2)) THEN
c
c         Connection pseudo-equilibrium - saddle
c         --------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-equilibrium - saddle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2*SCNDIM+3
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          DO I=1,SCNDIM
            ICP(SCNICP+2+I)=SCIPAR0+4+I
            ICP(SCNICP+2+SCNDIM+I)=SCIPAR0+4+SCNDIM+I
          END DO
          ICP(SCNICP+2*SCNDIM+3)=SCIPAR0+5+2*SCNDIM
          NBC=3*SCNDIM+4
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.PCS1).OR.(SCIPS.EQ.PCS2)) THEN
c
c         Connection pseudo-equilibrium - crossing - saddle
c         -------------------------------------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Connection pseudo-equilibrium - crossing - ' //
     +          'saddle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP+2*SCNDIM+3
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          ICP(SCNICP+1)=SCIPAR0+1
          ICP(SCNICP+2)=SCIPAR0+2
          DO I=1,SCNDIM
            ICP(SCNICP+2+I)=SCIPAR0+4+I
            ICP(SCNICP+2+SCNDIM+I)=SCIPAR0+4+SCNDIM+I
          END DO
          ICP(SCNICP+2*SCNDIM+3)=SCIPAR0+5+2*SCNDIM
          NBC=4*SCNDIM+5
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.SCY1).OR.(SCIPS.EQ.SCY2)) THEN
c
c         Sliding cycle
c         -------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Sliding cycle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=2*SCNDIM+2
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.SCC1).OR.(SCIPS.EQ.SCC2)) THEN
c
c         Sliding-crossing cycle
c         ----------------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Sliding-crossing cycle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=3*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=3*SCNDIM+3
          NINT=0
          IF (SCIDIFF.GE.2) THEN
            JAC=1
          ELSE IF (SCIDIFF.GE.1) THEN
            JAC=0
          ELSE
            WRITE(*,540)1
            STOP
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=3*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            ITHU(2*SCNTHU+I)=2*SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
            THU(ITHU(2*SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE IF ((SCIPS.EQ.CCY).OR.(SCIPS.EQ.CCY)) THEN
c
c         Crossing cycle
c         --------------
c
c         Debug
          IF (DEBUG) THEN
            IF (DBGLEV.GE.DBGL2) THEN
              PRINT *,'Crossing cycle'
            END IF
          END IF
c
c         AUTO97 constants
          NDIM=2*SCNDIM
          IPS=4
          IRS=SCIRS
          NICP=SCNICP
          DO I=1,SCNICP
            ICP(I)=SCICP(I)
          END DO
          NBC=2*SCNDIM+2
          NINT=0
          IF (SCIDIFF.GE.1) THEN
            JAC=1
          ELSE
            WRITE(*,610)1
            JAC=0
          END IF
          NTHL=SCNTHL
          DO I=1,SCNTHL
            ITHL(I)=SCITHL(I)
            THL(ITHL(I))=SCTHL(SCITHL(I))
          END DO
          NTHU=2*SCNTHU
          DO I=1,SCNTHU
            ITHU(I)=SCITHU(I)
            ITHU(SCNTHU+I)=SCNDIM+SCITHU(I)
            THU(ITHU(I))=SCTHU(SCITHU(I))
            THU(ITHU(SCNTHU+I))=SCTHU(SCITHU(I))
          END DO
          NUZR=SCNUZR
          DO I=1,SCNUZR
            IUZR(I)=SCIUZR(I)
            UZR(I)=SCUZR(I)
          END DO
c
        ELSE
          WRITE(*,510)SCIPS
          STOP
        END IF
c
c       Check for dimension limits
        IF (SCNDIM.GT.SCNDIMX) THEN
          WRITE(*,552)
          STOP
        ELSE IF (SCNPSIX+SCIPSI0.GE.SCIPARTS) THEN
          WRITE(*,554)
          STOP
        ELSE IF (NDIM.GT.NDIMX) THEN
          WRITE(*,556)
          STOP
        ELSE IF (NBC.GT.NBCX) THEN
          WRITE(*,558)
          STOP
        ELSE IF (ICP(NICP).GT.NPARX) THEN
          WRITE(*,560)
          STOP
        END IF
c
c       Test function activation
c       ------------------------
        IF (SCNPSI.GT.0) THEN
          DO I=1,SCNPSI
            SCFPSI(SCIPSI(I))=.TRUE.
            ICP(NICP+I)=SCIPSI(I)+SCIPSI0
            IUZR(NUZR+I)=SCIPSI(I)+SCIPSI0
            UZR(NUZR+I)=0.0
          END DO
          NICP=NICP+SCNPSI
          NUZR=NUZR+SCNPSI
        END IF
c
c       Write fort.12 (r.xxx)
c       ---------------------
        WRITE(12,FMT=310)NDIM,IPS,IRS,ILP
        F(1)='('
        F(2)='I10'
        DO I=1,NICP
          F(2+I)=','' '',I10'
        END DO
        F(3+NICP)=',T150,''NICP,(ICP(I),I=1,NICP)'')'
        WRITE(12,FMT=F)NICP,(ICP(I),I=1,NICP)
        WRITE(12,FMT=330)NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT
        WRITE(12,FMT=340)NMX,RL0,RL1,A0,A1
        WRITE(12,FMT=350)NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC
        WRITE(12,FMT=360)EPSL,EPSU,EPSS
        WRITE(12,FMT=370)DS,DSMIN,DSMAX,IADS
        WRITE(12,FMT=380)NTHL
        WRITE(12,FMT=410)(ITHL(I),THL(ITHL(I)),I=1,NTHL)
        WRITE(12,FMT=390)NTHU
        WRITE(12,FMT=410)(ITHU(I),THU(ITHU(I)),I=1,NTHU)
        WRITE(12,FMT=400)NUZR
        WRITE(12,FMT=410)(IUZR(I),UZR(I),I=1,NUZR)
c
c       Write scprob.f
c       --------------
C----------------------------------------------------------------------
C----------------------------------------------------------------------
C                               scprob.f
C----------------------------------------------------------------------
C----------------------------------------------------------------------


        FPROB(1)= '(''C--------------------------------------------'//
     +    '--------------------------\n'','
        FPROB(2)= '''C---------------------------------------------'//
     +    '-------------------------\n'','
        FPROB(3)= '''C                               scprob.f\n'','
        FPROB(4)= '''C---------------------------------------------'//
     +    '-------------------------\n'','
        FPROB(5)= '''C---------------------------------------------'//
     +    '-------------------------\n'','
        FPROB(6)= '''C\n'','
        FPROB(7)= '''C     SlideCont\n'','
        FPROB(8)= '''C\n'','
        FPROB(9)= '''C     An AUTO97 driver for sliding bifurcation'//
     +    'analysis\n'','
        FPROB(10)= '''C\n'','
        FPROB(11)= '''C     BY  Fabio Dercole & Yuri Kuznetsov\n'','
        FPROB(12)= '''C\n'','
        FPROB(13)='''C\n'','
        FPROB(14)='''C     VERSION 1.0 (last revision 5/2002)\n'','
        FPROB(15)='''C\n'','
        FPROB(16)='''C---------------------------------------------'//
     +    '-------------------------\n'','
        FPROB(17)='''C\n'','
        FPROB(18)='''C     *********************************\n'','
        FPROB(19)='''C     *                               *\n'','
        FPROB(20)='''C     *  SlideCont test problem file  *\n'','
        FPROB(21)='''C     *                               *\n'','
        FPROB(22)='''C     *********************************\n'','
        FPROB(23)='''C\n'','
        FPROB(24)='''C---------------------------------------------'//
     +    '-------------------------\n'','
        FPROB(25)='''C\n'','
        FPROB(26)='''c     -----------------\n'','
        FPROB(27)='''      SUBROUTINE SCPROB\n'','
        FPROB(28)='''c     -----------------\n'','
        FPROB(29)='''c\n'','
        FPROB(30)='''        IMPLICIT DOUBLE PRECISION (A-H,O-Z)\n'','
        FPROB(31)='''c\n'','
        FPROB(32)='''        INCLUDE ''''slidecont.h''''\n'','
        FPROB(33)='''c\n'','
        FPROB(34)='''c       Common block reference\n'','
        FPROB(35)='''c       ----------------------\n'','
        FPROB(36)='''        LOGICAL DEFINED\n'','
        FPROB(37)='''        INTEGER SCNDIM,SCIPS,SCIRS,SCISTART\n'','
        FPROB(38)='''        INTEGER SCNICP,SCICP(SCNPARX)\n'','
        FPROB(39)='''        INTEGER SCNPSI,SCIPSI(SCNPSIX)\n'','
        FPROB(40)='''        INTEGER SCNFIXED,SCIFIXED(SCNPSIX)\n'','
        FPROB(41)='''        INTEGER SCIDIFF,SCNUZR\n'','
        FPROB(42)=
     +    '''        LOGICAL SCFPSI(SCNPSIX),SCFFIXED(SCNPSIX)\n'','
        FPROB(43)='''c\n'','
        FPROB(44)=
     +    '''        COMMON /PROB/ DEFINED\n'','
        FPROB(45)=
     +    '''        COMMON /PROB/ SCNDIM,SCIPS,SCIRS,SCISTART\n'','
        FPROB(46)='''        COMMON /PROB/ SCNICP,SCICP\n'','
        FPROB(47)='''        COMMON /PROB/ SCNPSI,SCIPSI\n'','
        FPROB(48)='''        COMMON /PROB/ SCNFIXED,SCIFIXED\n'','
        FPROB(49)='''        COMMON /PROB/ SCIDIFF,SCNUZR\n'','
        FPROB(50)='''        COMMON /PROB/ SCFPSI,SCFFIXED\n'','
        FPROB(51)='''c\n'','
        FPROB(52)='''c       Zero initialization\n'','
        FPROB(53)='''c       -------------------\n'','
        FPROB(54)='''        DATA SCICP/SCNPARX*0/\n'','
        FPROB(55)='''        DATA SCIPSI/SCNPSIX*0/\n'','
        FPROB(56)='''        DATA SCIFIXED/SCNPSIX*0/\n'','
        FPROB(57)='''        DATA SCFPSI/SCNPSIX*.FALSE./\n'','
        FPROB(58)='''        DATA SCFFIXED/SCNPSIX*.FALSE./\n'','
        FPROB(59)='''c\n'','
        FPROB(60)='''c       Problem constants\n'','
        FPROB(61)='''c       -----------------\n'','
        FPROB(62)='''        SCNDIM      ='',I4,''\n'','
        FPROB(63)='''        SCIPS       ='',I4,''\n'','
        FPROB(64)='''        SCIRS       ='',I4,''\n'','
        FPROB(65)='''        SCISTART    ='',I4,''\n'','
        FPROB(66)='''        SCNICP      ='',I4,''\n'','
        IF (SCNICP.GT.0) THEN
          DO I=1,SCNICP
            FPROB(66+I)='''        SCICP('',I1,'')    ='',I4,''\n'','
          END DO
        END IF
        FPROB(67+SCNICP)='''        SCNPSI      ='',I4,''\n'','
        IF (SCNPSI.GT.0) THEN
          DO I=1,SCNPSI
            FPROB(67+SCNICP+I)=
     +        '''        SCIPSI('',I1,'')   ='',I4,''\n'','
          END DO
        END IF
        FPROB(68+SCNICP+SCNPSI)='''        SCNFIXED    ='',I4,''\n'','
        IF (SCNFIXED.GT.0) THEN
          DO I=1,SCNFIXED
            FPROB(68+SCNICP+SCNPSI+I)=
     +        '''        SCIFIXED('',I1,'') ='',I4,''\n'','
          END DO
        END IF
        FPROB(69+SCNICP+SCNPSI+SCNFIXED)=
     +    '''        SCIDIFF     ='',I4,''\n'','
        FPROB(70+SCNICP+SCNPSI+SCNFIXED)=
     +    '''        SCNUZR      ='',I4,''\n'','
        FPROB(71+SCNICP+SCNPSI+SCNFIXED)='''c\n'','
        FPROB(72+SCNICP+SCNPSI+SCNFIXED)=
     +    '''c       Test function activation\n'','
        FPROB(73+SCNICP+SCNPSI+SCNFIXED)=
     +    '''c       ------------------------\n'','
        FPROB(74+SCNICP+SCNPSI+SCNFIXED)=
     +    '''        IF (SCNPSI.GT.0) THEN\n'','
        FPROB(75+SCNICP+SCNPSI+SCNFIXED)=
     +    '''          DO I=1,SCNPSI\n'','
        FPROB(76+SCNICP+SCNPSI+SCNFIXED)=
     +    '''            SCFPSI(SCIPSI(I))=.TRUE.\n'','
        FPROB(77+SCNICP+SCNPSI+SCNFIXED)=
     +    '''          END DO\n'','
        FPROB(78+SCNICP+SCNPSI+SCNFIXED)=
     +    '''        END IF\n'','
        FPROB(79+SCNICP+SCNPSI+SCNFIXED)='''c\n'','
        FPROB(80+SCNICP+SCNPSI+SCNFIXED)=
     +    '''c       Mark the common block as defined\n'','
        FPROB(81+SCNICP+SCNPSI+SCNFIXED)=
     +    '''c       --------------------------------\n'','
        FPROB(82+SCNICP+SCNPSI+SCNFIXED)=
     +    '''        DEFINED=.TRUE.\n'','
        FPROB(83+SCNICP+SCNPSI+SCNFIXED)='''c\n'','
        FPROB(84+SCNICP+SCNPSI+SCNFIXED)='''      RETURN\n'','
        FPROB(85+SCNICP+SCNPSI+SCNFIXED)='''      END\n'')'
c
        WRITE(3,FMT=FPROB)SCNDIM,SCIPS,SCIRS,SCISTART,SCNICP,
     +    (I,SCICP(I),I=1,SCNICP),SCNPSI,(I,SCIPSI(I),I=1,SCNPSI),
     +    SCNFIXED,(I,SCIFIXED(I),I=1,SCNFIXED),SCIDIFF,SCNUZR
c
c       Close files
c       -----------
        CLOSE(2,STATUS='KEEP')
        CLOSE(3,STATUS='KEEP')
        CLOSE(12,STATUS='KEEP')
c
c       Debug output formats
c       -------------------- 
 110    FORMAT(I10,' ',I10,' ',I10,' ',I10,T150,
     +    'NDIM,IPS,IRS,ILP')
 130    FORMAT(I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',
     +    I10,' ',I10,T150,'NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT')
 140    FORMAT(I10,' ',D16.10,' ',D16.10,' ',D16.10,' ',D16.10,T150,
     +    'NMX,RL0,RL1,A0,A1')
 150    FORMAT(I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,
     +    ' ',I10,T150,
     +    'NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC')
 160    FORMAT(D16.10,' ',D16.10,' ',D16.10,T150,
     +    'EPSL,EPSU,EPSS')
 170    FORMAT(D16.10,' ',D16.10,' ',D16.10,' ',I10,T150,
     +    'DS,DSMIN,DSMAX,IADS')
 180    FORMAT(I10,T150,
     +    'NTHL,((ITHL(I),THL(I)),I=1,NTHL)')
 190    FORMAT(I10,T150,
     +    'NTHU,((ITHU(I),THU(I)),I=1,NTHU)')
 200    FORMAT(I10,T150,
     +    'NUZR,((IUZR(I),UZR(I)),I=1,NUZR)')
 210    FORMAT(I10,' ',D16.10)
 220    FORMAT(I10,' ',I10,T150,'SCISTART,SCIDIFF')
c
c       fort.12 (r.xxx) output formats
c       ------------------------------ 
 310    FORMAT(I10,' ',I10,' ',I10,' ',I10,T150,
     +    'NDIM,IPS,IRS,ILP')
 330    FORMAT(I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',
     +    I10,T150,'NTST,NCOL,IAD,ISP,ISW,IPLT,NBC,NINT')
 340    FORMAT(I10,' ',D16.10,' ',D16.10,' ',D16.10,' ',D16.10,T150,
     +    'NMX,RL0,RL1,A0,A1')
 350    FORMAT(I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,' ',I10,
     +    T150,'NPR,MXBF,IID,ITMX,ITNW,NWTN,JAC')
 360    FORMAT(D16.10,' ',D16.10,' ',D16.10,T150,
     +    'EPSL,EPSU,EPSS')
 370    FORMAT(D16.10,' ',D16.10,' ',D16.10,' ',I10,T150,
     +    'DS,DSMIN,DSMAX,IADS')
 380    FORMAT(I10,T150,
     +    'NTHL,((ITHL(I),THL(I)),I=1,NTHL)')
 390    FORMAT(I10,T150,
     +    'NTHU,((ITHU(I),THU(I)),I=1,NTHU)')
 400    FORMAT(I10,T150,
     +    'NUZR,((IUZR(I),UZR(I)),I=1,NUZR)')
 410    FORMAT(I10,' ',D16.10)
c
      STOP
      END

